@@ -10,7 +10,6 @@ from pulpcore.plugin.models import (
     Content,
     Remote,
     Repository,
-    RepositoryVersion,
     Distribution,
     Task,
 )
@@ -58,7 +57,7 @@ class CollectionImport(models.Model):
     task = models.OneToOneField(
         Task, on_delete=models.CASCADE, editable=False, related_name="+", primary_key=True
     )
-    messages = psql_fields.JSONField(default=list, editable=False)
+    messages = models.JSONField(default=list, editable=False)
 
     class Meta:
         ordering = ["task__pulp_created"]
@@ -101,14 +100,14 @@ class CollectionVersion(Content):
     Fields:
 
         authors (psql_fields.ArrayField): A list of the CollectionVersion content's authors.
-        contents (psql_fields.JSONField): A JSON field with data about the contents.
-        dependencies (psql_fields.JSONField): A dict declaring Collections that this collection
+        contents (models.JSONField): A JSON field with data about the contents.
+        dependencies (models.JSONField): A dict declaring Collections that this collection
             requires to be installed for it to be usable.
         description (models.TextField): A short summary description of the collection.
-        docs_blob (psql_fields.JSONField): A JSON field holding the various documentation blobs in
+        docs_blob (models.JSONField): A JSON field holding the various documentation blobs in
             the collection.
-        manifest (psql_fields.JSONField): A JSON field holding MANIFEST.json data.
-        files (psql_fields.JSONField): A JSON field holding FILES.json data.
+        manifest (models.JSONField): A JSON field holding MANIFEST.json data.
+        files (models.JSONField): A JSON field holding FILES.json data.
         documentation (models.CharField): The URL to any online docs.
         homepage (models.CharField): The URL to the homepage of the collection/project.
         issues (models.CharField): The URL to the collection issue tracker.
@@ -131,12 +130,12 @@ class CollectionVersion(Content):
 
     # Data Fields
     authors = psql_fields.ArrayField(models.CharField(max_length=64), default=list, editable=False)
-    contents = psql_fields.JSONField(default=list, editable=False)
-    dependencies = psql_fields.JSONField(default=dict, editable=False)
+    contents = models.JSONField(default=list, editable=False)
+    dependencies = models.JSONField(default=dict, editable=False)
     description = models.TextField(default="", blank=True, editable=False)
-    docs_blob = psql_fields.JSONField(default=dict, editable=False)
-    manifest = psql_fields.JSONField(default=dict, editable=False)
-    files = psql_fields.JSONField(default=dict, editable=False)
+    docs_blob = models.JSONField(default=dict, editable=False)
+    manifest = models.JSONField(default=dict, editable=False)
+    files = models.JSONField(default=dict, editable=False)
     documentation = models.CharField(default="", blank=True, max_length=2000, editable=False)
     homepage = models.CharField(default="", blank=True, max_length=2000, editable=False)
     issues = models.CharField(default="", blank=True, max_length=2000, editable=False)
@@ -227,6 +226,21 @@ class CollectionRemote(Remote):
         default_related_name = "%(app_label)s_%(model_name)s"
 
 
+class AnsibleCollectionDeprecated(Content):
+    """
+    A model that represents if a Collection is `deprecated` for a given RepositoryVersion.
+    """
+
+    TYPE = "collection_deprecation"
+
+    namespace = models.CharField(max_length=64, editable=False)
+    name = models.CharField(max_length=64, editable=False)
+
+    class Meta:
+        default_related_name = "%(app_label)s_%(model_name)s"
+        unique_together = ("namespace", "name")
+
+
 class AnsibleRepository(Repository):
     """
     Repository for "ansible" content.
@@ -237,7 +251,7 @@ class AnsibleRepository(Repository):
     """
 
     TYPE = "ansible"
-    CONTENT_TYPES = [Role, CollectionVersion]
+    CONTENT_TYPES = [Role, CollectionVersion, AnsibleCollectionDeprecated]
     REMOTE_TYPES = [RoleRemote, CollectionRemote]
 
     last_synced_metadata_time = models.DateTimeField(null=True)
@@ -247,50 +261,6 @@ class AnsibleRepository(Repository):
 
         permissions = (("modify_ansible_repo_content", "Can modify ansible repository content"),)
 
-    def finalize_new_version(self, new_version):
-        """
-        Finalize the incomplete RepositoryVersion with correct repository-level metadata.
-
-        `AnsibleCollectionDeprecated` objects may need to be created for the new
-        `RepositoryVersion`.
-
-        Args:
-            new_version (pulpcore.app.models.RepositoryVersion): The incomplete RepositoryVersion to
-                finalize.
-
-        """
-        deprecated_in_prev_version_qs = Collection.objects.filter(
-            ansiblecollectiondeprecated__repository_version=new_version.previous()
-        )
-        collection_versions_removed_pks = new_version.removed().values("pk")
-        deprecated_in_this_version = deprecated_in_prev_version_qs.exclude(
-            versions__in=collection_versions_removed_pks
-        )
-        to_deprecate = []
-        for collection_deprecated in deprecated_in_this_version:
-            to_deprecate.append(
-                AnsibleCollectionDeprecated(
-                    repository_version=new_version, collection=collection_deprecated
-                )
-            )
-
-        if to_deprecate:
-            AnsibleCollectionDeprecated.objects.bulk_create(to_deprecate, ignore_conflicts=True)
-
-
-class AnsibleCollectionDeprecated(BaseModel):
-    """
-    A model that represents if a Collection is `deprecated` for a given RepositoryVersion.
-    """
-
-    repository_version = models.ForeignKey(
-        RepositoryVersion, on_delete=models.CASCADE, related_name="collection_memberships"
-    )
-    collection = models.ForeignKey(Collection, on_delete=models.CASCADE)
-
-    class Meta:
-        unique_together = ("collection", "repository_version")
-
 
 class AnsibleDistribution(Distribution):
     """
