@@ -12,6 +12,7 @@ from aiohttp.client_exceptions import ClientResponseError
 from async_lru import alru_cache
 from django.conf import settings
 from django.db import transaction
+from django.db.models import Q
 from django.urls import reverse
 from django.utils.dateparse import parse_datetime
 from galaxy_importer.collection import import_collection as process_collection
@@ -19,7 +20,6 @@ from galaxy_importer.collection import CollectionFilename
 from galaxy_importer.exceptions import ImporterError
 from pkg_resources import Requirement
 
-from pulpcore.plugin.constants import TASK_STATES
 from pulpcore.plugin.models import (
     Artifact,
     ContentArtifact,
@@ -122,10 +122,25 @@ def sync(remote_pk, repository_pk, mirror, optimize):
     remote = CollectionRemote.objects.get(pk=remote_pk)
     repository = AnsibleRepository.objects.get(pk=repository_pk)
 
+    is_repo_remote = False
+    if repository.remote:
+        is_repo_remote = remote.pk == repository.remote.pk
+
     if not remote.url:
         raise ValueError(_("A CollectionRemote must have a 'url' specified to synchronize."))
 
-    first_stage = CollectionSyncFirstStage(remote, repository, optimize)
+    deprecation_before_sync = set()
+    for namespace, name in AnsibleCollectionDeprecated.objects.filter(
+        pk__in=repository.latest_version().content
+    ).values_list("namespace", "name"):
+        deprecation_before_sync.add(f"{namespace}.{name}")
+    first_stage = CollectionSyncFirstStage(
+        remote, repository, is_repo_remote, deprecation_before_sync, optimize
+    )
+    if first_stage.should_sync is False:
+        log.debug(_("no-op: remote wasn't updated since last sync."))
+        return
+
     d_version = AnsibleDeclarativeVersion(first_stage, repository, mirror=mirror)
     repo_version = d_version.create()
 
@@ -136,10 +151,16 @@ def sync(remote_pk, repository_pk, mirror, optimize):
         repository.last_synced_metadata_time = first_stage.last_synced_metadata_time
         repository.save()
 
-    deprecated = AnsibleCollectionDeprecated.objects.filter(pk__in=repo_version.content)
-    RepositoryContent.objects.filter(repository=repository, content__in=deprecated).exclude(
-        version_added=repo_version
-    ).all().update(version_removed=repo_version)
+    to_undeprecate = Q()
+    undeprecated = deprecation_before_sync.difference(first_stage.deprecation_after_sync)
+    if undeprecated:
+        for collection in undeprecated:
+            namespace, name = collection.split(".")
+            to_undeprecate |= Q(namespace=namespace, name=name)
+        deprecated = AnsibleCollectionDeprecated.objects.filter(to_undeprecate)
+        RepositoryContent.objects.filter(
+            repository=repository, content__in=deprecated
+        ).all().update(version_removed=repo_version)
 
 
 def import_collection(
@@ -349,20 +370,24 @@ class CollectionSyncFirstStage(Stage):
     The first stage of a pulp_ansible sync pipeline.
     """
 
-    def __init__(self, remote, repository, optimize):
+    def __init__(self, remote, repository, is_repo_remote, deprecation_before_sync, optimize):
         """
         The first stage of a pulp_ansible sync pipeline.
 
         Args:
             remote (CollectionRemote): The remote data to be used when syncing
             repository (AnsibleRepository): The repository being syncedself.
+            is_repo_remote (bool): True if the remote is the repository's remote.
+            deprecation_before_sync (set): Set of deprecations before the sync.
             optimize (boolean): Whether to optimize sync or not.
 
         """
         super().__init__()
         self.remote = remote
         self.repository = repository
-        self.optimize = optimize
+        self.is_repo_remote = is_repo_remote
+        self.deprecation_before_sync = deprecation_before_sync
+        self.deprecation_after_sync = set()
         self.collection_info = parse_collections_requirements_file(remote.requirements_file)
         self.add_dependents = self.collection_info and self.remote.sync_dependencies
         self.already_synced = set()
@@ -373,6 +398,11 @@ class CollectionSyncFirstStage(Stage):
         # Interpret download policy
         self.deferred_download = self.remote.policy != Remote.IMMEDIATE
 
+        # Check if we should sync
+        self.should_sync = not optimize or asyncio.get_event_loop().run_until_complete(
+            self._should_we_sync()
+        )
+
     @alru_cache(maxsize=128)
     async def _get_root_api(self, root):
         """
@@ -518,6 +548,7 @@ class CollectionSyncFirstStage(Stage):
                         d_content = DeclarativeContent(
                             content=AnsibleCollectionDeprecated(namespace=namespace, name=name),
                         )
+                        self.deprecation_after_sync.add(f"{namespace}.{name}")
                         await self.put(d_content)
                     tasks.append(
                         loop.create_task(
@@ -538,10 +569,19 @@ class CollectionSyncFirstStage(Stage):
         tasks = []
         loop = asyncio.get_event_loop()
 
+        if (
+            namespace not in self._unpaginated_collection_metadata
+            or name not in self._unpaginated_collection_metadata[namespace]
+        ):
+            raise FileNotFoundError(
+                f"Collection {namespace}.{name} does not exist on {self.remote.url}"
+            )
+
         if self._unpaginated_collection_metadata[namespace][name]["deprecated"]:
             d_content = DeclarativeContent(
                 content=AnsibleCollectionDeprecated(namespace=namespace, name=name),
             )
+            self.deprecation_after_sync.add(f"{namespace}.{name}")
             await self.put(d_content)
 
         all_versions_of_collection = self._unpaginated_collection_version_metadata[namespace][name]
@@ -643,6 +683,9 @@ class CollectionSyncFirstStage(Stage):
                             namespace=collection["namespace"], name=collection["name"]
                         ),
                     )
+                    self.deprecation_after_sync.add(
+                        f"{collection['namespace']}.{collection['name']}"
+                    )
                     await self.put(d_content)
 
         for collections_in_namespace in self._unpaginated_collection_version_metadata.values():
@@ -705,46 +748,39 @@ class CollectionSyncFirstStage(Stage):
     async def _should_we_sync(self):
         """Check last synced metadata time."""
         msg = _("no_change: Checking if remote changed since last sync.")
-        noop = ProgressReport(message=msg, code="sync.no_change")
-        noop.state = TASK_STATES.COMPLETED
-        noop.save()
-
-        if not self.repository.remote:
-            return True
-
-        if self.remote != self.repository.remote.cast():
-            return True
-
-        root, api_version = await self._get_root_api(self.remote.url)
-        if api_version == 3:
-            downloader = self.remote.get_downloader(
-                url=root, silence_errors_for_response_status_codes={404}
-            )
-            try:
-                metadata = parse_metadata(await downloader.run())
-            except FileNotFoundError:
+        async with ProgressReport(message=msg, code="sync.no_change") as noop:
+            if not self.is_repo_remote:
                 return True
 
-            try:
-                self.last_synced_metadata_time = parse_datetime(metadata["published"])
-            except KeyError:
-                return True
-
-            sources = set()
-            if self.collection_info:
-                sources = {r.source for r in self.collection_info if r.source}
-            sources.add(self.remote.url)
-            if len(sources) > 1:
-                return True
-
-            if self.last_synced_metadata_time == self.repository.last_synced_metadata_time:
-                noop.message = _(
-                    "no-op: {remote} did not change since last sync - {published}".format(
-                        remote=self.remote.url, published=self.last_synced_metadata_time
-                    )
+            root, api_version = await self._get_root_api(self.remote.url)
+            if api_version == 3:
+                downloader = self.remote.get_downloader(
+                    url=root, silence_errors_for_response_status_codes={404}
                 )
-                noop.save()
-                return False
+                try:
+                    metadata = parse_metadata(await downloader.run())
+                except FileNotFoundError:
+                    return True
+
+                try:
+                    self.last_synced_metadata_time = parse_datetime(metadata["published"])
+                except KeyError:
+                    return True
+
+                sources = set()
+                if self.collection_info:
+                    sources = {r.source for r in self.collection_info if r.source}
+                sources.add(self.remote.url)
+                if len(sources) > 1:
+                    return True
+
+                if self.last_synced_metadata_time == self.repository.last_synced_metadata_time:
+                    noop.message = _(
+                        "no-op: {remote} did not change since last sync - {published}".format(
+                            remote=self.remote.url, published=self.last_synced_metadata_time
+                        )
+                    )
+                    return False
 
         return True
 
@@ -752,12 +788,6 @@ class CollectionSyncFirstStage(Stage):
         """
         Build and emit `DeclarativeContent` from the ansible metadata.
         """
-        if self.optimize:
-            should_we_sync = await self._should_we_sync()
-            if should_we_sync is False:
-                log.debug(_("no-op: remote wasn't updated since last sync."))
-                return
-
         tasks = []
         loop = asyncio.get_event_loop()
 
@@ -879,7 +909,10 @@ class CollectionContentSaver(ContentSaver):
                     )
                     if runtime_metadata:
                         runtime_yaml = yaml.safe_load(runtime_metadata)
-                        collection_version.requires_ansible = runtime_yaml.get("requires_ansible")
+                        if runtime_yaml:
+                            collection_version.requires_ansible = runtime_yaml.get(
+                                "requires_ansible"
+                            )
                     manifest_data = json.load(
                         get_file_obj_from_tarball(tar, "MANIFEST.json", artifact.file.name)
                     )
