@@ -136,6 +136,35 @@ class SyncCollectionsFromPulpServerTestCase(TestCaseUsingBindings, SyncHelpersMi
         messages = [r.message for r in task.progress_reports]
         self.assertIn(msg, str(messages))
 
+    def test_noop_resync_with_mirror_from_pulp(self):
+        """Test whether no-op sync with mirror=True doesn't remove repository content."""
+        second_body = gen_ansible_remote(
+            url=self.distribution.client_url,
+            requirements_file=self.requirements_file,
+            sync_dependencies=False,
+        )
+        second_remote = self.remote_collection_api.create(second_body)
+        self.addCleanup(self.remote_collection_api.delete, second_remote.pulp_href)
+
+        second_repo = self._create_repo_and_sync_with_remote(second_remote)
+
+        second_content = self.cv_api.list(repository_version=f"{second_repo.pulp_href}versions/1/")
+        self.assertGreaterEqual(len(second_content.results), 1)
+
+        # Resync
+        repository_sync_data = AnsibleRepositorySyncURL(
+            remote=second_remote.pulp_href, optimize=True, mirror=True
+        )
+        sync_response = self.repo_api.sync(second_repo.pulp_href, repository_sync_data)
+        monitor_task(sync_response.task)
+        second_repo = self.repo_api.read(second_repo.pulp_href)
+        self.assertEqual(int(second_repo.latest_version_href[-2]), 1)
+        task = tasks.read(sync_response.task)
+
+        msg = "no-op: {url} did not change since last sync".format(url=second_remote.url)
+        messages = [r.message for r in task.progress_reports]
+        self.assertIn(msg, str(messages))
+
     def test_update_requirements_file(self):
         """Test requirements_file update."""
         body = gen_ansible_remote(
@@ -157,6 +186,23 @@ class SyncCollectionsFromPulpServerTestCase(TestCaseUsingBindings, SyncHelpersMi
         repo = self.repo_api.read(repo.pulp_href)
         self.assertIsNone(repo.last_synced_metadata_time)
 
+    def test_sync_with_missing_collection(self):
+        """Test that syncing with a non-present collection gives a useful error."""
+        body = gen_ansible_remote(
+            url=self.distribution.client_url,
+            requirements_file="collections:\n  - absent.not_present",
+            sync_dependencies=False,
+        )
+        remote = self.remote_collection_api.create(body)
+        self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
+
+        with self.assertRaises(PulpTaskError) as cm:
+            self._create_repo_and_sync_with_remote(remote)
+
+        task_result = cm.exception.task.to_dict()
+        msg = "absent.not_present does not exist"
+        self.assertIn(msg, task_result["error"]["description"], task_result["error"]["description"])
+
 
 @unittest.skipUnless(
     "AUTOMATION_HUB_TOKEN_AUTH" in os.environ,
